import unittest
from unittest.mock import Mock

from src.custom_logging import local_thread
from src.custom_logging.middlewares import capture_request


class TestMiddleware(unittest.TestCase):
    def setUp(self):
        # clear local_thread
        if getattr(local_thread, "request", None):
            del local_thread.request

    def test_capture_request(self):
        request = Mock()
        middleware = capture_request(Mock())

        self.assertIsNone(getattr(local_thread, "request", None))
        middleware(request)
        self.assertIsNotNone(getattr(local_thread, "request", None))


if __name__ == "__main__":
    unittest.main()



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-custom-logging",
    author="Seonghyeon Cho",
    author_email="seonghyeoncho96@gmail.com",
    description="Django middleware for custom format logging",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/sh-cho/django-custom-logging",
    project_urls={
        "Bug Tracker": "https://github.com/sh-cho/django-custom-logging/issues",
        "Source Code": "https://github.com/sh-cho/django-custom-logging",
    },
    classifiers=[
        # see https://pypi.org/classifiers/
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)



from functools import reduce


class NoDefaultProvided:
    """dummy class for getattrd"""

    pass


def getattrd(obj, name, default=NoDefaultProvided):
    """
    Same as getattr(), but allows dot notation lookup
    Discussed in: http://stackoverflow.com/questions/11975781
    """
    try:
        return reduce(getattr, name.split("."), obj)
    except AttributeError:
        if default != NoDefaultProvided:
            return default
        raise


def setattrd(obj, name, val):
    pre, _, post = name.rpartition(".")
    return setattr(getattrd(obj, pre, None) if pre else obj, post, val)



import logging
from logging import Filter, LogRecord

from . import local_thread
from .exceptions import CaptureListValidationException
from .utils import getattrd


logger = logging.getLogger(__name__)


class CustomFilter(Filter):
    def __init__(self, capture_list=None, *args, **kwargs):
        super().__init__()
        if not isinstance(capture_list, (list, tuple)):
            raise CaptureListValidationException

        self.capture_list = capture_list

    def filter(self, record: LogRecord) -> bool:
        for capture_in, capture_out in self.capture_list:
            # FIXME: default value should be differ by its type
            setattr(record, capture_out, getattrd(local_thread, capture_in, "-"))

        return True
